aboutsummaryrefslogtreecommitdiff
path: root/libbuild2/script/timeout.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'libbuild2/script/timeout.hxx')
-rw-r--r--libbuild2/script/timeout.hxx6
1 files changed, 4 insertions, 2 deletions
diff --git a/libbuild2/script/timeout.hxx b/libbuild2/script/timeout.hxx
index 9991ad6..4ab43a5 100644
--- a/libbuild2/script/timeout.hxx
+++ b/libbuild2/script/timeout.hxx
@@ -10,12 +10,13 @@
namespace build2
{
// Parse the specified in seconds timeout returning it if the value is not
// zero and nullopt otherwise. Issue diagnostics and fail if the argument is
// not a valid timeout.
//
optional<duration>
parse_timeout (const string&,
const char* what,
+ const char* prefix = "",
const location& = location ());
// As above, but return the timepoint which is away from now by the
@@ -24,6 +25,7 @@ namespace build2
optional<timestamp>
parse_deadline (const string&,
const char* what,
+ const char* prefix = "",
const location& = location ());
// Return the earlier timeout/deadline of two values, if any is present.
@@ -10,12 +10,13 @@
{
// Parse the specified in seconds timeout returning it if the value is not
- // zero and nullopt otherwise. Issue diagnostics and fail if the argument is
- // not a valid timeout.
+ // zero and nullopt otherwise. Issue diagnostics with an optional prefix and
+ // fail if the argument is not a valid timeout.
//
optional<duration>